;; Generated package description from cperl-mode.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "cperl-mode" "32.0.50" "Perl code editing commands" '((emacs "26.1")) :commit "ca03a4c3857b46f24613d1b4dc87299847fdaf19" :authors '(("Ilya Zakharevich" . "ilyaz@cpan.org") ("Jonathan Rockway" . "jon@jrock.us")) :maintainer '(nil . "emacs-devel@gnu.org") :keywords '("languages") :url "https://github.com/HaraldJoerg/cperl-mode/issues/32")
